@@ -3,4 +3,4 @@ from client import client
 
 def test_hello(client):
     resp = client.get("/hello")
-    assert resp.data == b'hello'
+    assert resp.data == b"hello"
